@@ -63,7 +63,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 namespace nmc {
 
-DkPreferenceWidget::DkPreferenceWidget(QWidget* parent) : DkWidget(parent) {
+DkPreferenceWidget::DkPreferenceWidget(QWidget* parent) : DkFadeWidget(parent) {
 
 	createLayout();
 
@@ -107,24 +107,19 @@ void DkPreferenceWidget::createLayout() {
 	mCentralLayout = new QStackedLayout(centralWidget);
 	mCentralLayout->setContentsMargins(0, 0, 0, 0);
 
-	QWidget* dummy = new QWidget(this);
-	QHBoxLayout* layout = new QHBoxLayout(dummy);
-	layout->setContentsMargins(0, 0, 0, 0);
-	layout->setSpacing(0);
-	layout->setAlignment(Qt::AlignLeft);
-	layout->addWidget(tabs);
-	layout->addWidget(centralWidget);
-
 	// add a scroll area
-	DkResizableScrollArea* scrollArea = new DkResizableScrollArea(this);
-	scrollArea->setObjectName("DkScrollAreaPlots");
-	scrollArea->setWidgetResizable(true);
-	scrollArea->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-	scrollArea->setWidget(dummy);
+	DkResizableScrollArea* scrollAreaTabs = new DkResizableScrollArea(this);
+	scrollAreaTabs->setObjectName("DkPreferenceTabsScroller");
+	scrollAreaTabs->setWidgetResizable(true);
+	scrollAreaTabs->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+	scrollAreaTabs->setWidget(tabs);
 
-	QVBoxLayout* sL = new QVBoxLayout(this);
-	sL->setContentsMargins(1, 1, 1, 1);	// 1 to get the border
-	sL->addWidget(scrollArea);
+	QHBoxLayout* sL = new QHBoxLayout(this);
+	sL->setContentsMargins(0, 0, 0, 0);	// use 1 to get the border
+	sL->setSpacing(0);
+	sL->setAlignment(Qt::AlignLeft);
+	sL->addWidget(scrollAreaTabs);
+	sL->addWidget(centralWidget);
 }
 
 void DkPreferenceWidget::addTabWidget(DkPreferenceTabWidget* tabWidget) {
@@ -196,34 +191,41 @@ void DkPreferenceTabWidget::createLayout() {
 	QLabel* titleLabel = new QLabel(name(), this);
 	titleLabel->setObjectName("DkPreferenceTitle");
 
+	// add a scroll area
+	mCentralScroller = new DkResizableScrollArea(this);
+	mCentralScroller->setObjectName("DkPreferenceScroller");
+	mCentralScroller->setWidgetResizable(true);
+
 	mInfoButton = new QPushButton(tr(""), this);
 	mInfoButton->setObjectName("infoButton");
 	mInfoButton->setFlat(true);
+	mInfoButton->setVisible(false);
 	connect(mInfoButton, SIGNAL(clicked()), this, SIGNAL(restartSignal()));
 
-	mLayout = new QGridLayout(this);
-	mLayout->setContentsMargins(0, 0, 0, 0);
-	mLayout->setAlignment(Qt::AlignTop);
-	mLayout->addWidget(titleLabel, 0, 0);
-	
-	mLayout->addWidget(mInfoButton, 2, 0, Qt::AlignBottom);
+	QGridLayout* l = new QGridLayout(this);
+	l->setContentsMargins(0, 0, 0, 0);
+	l->setAlignment(Qt::AlignTop);
+	l->addWidget(titleLabel, 0, 0);
+	l->addWidget(mCentralScroller, 1, 0);
+	l->addWidget(mInfoButton, 2, 0, Qt::AlignBottom);
 }
 
 void DkPreferenceTabWidget::setWidget(QWidget* w) {
 
-	mCentralWidget = w;
-	mCentralWidget->setObjectName("DkPreferenceWidget");
-	mLayout->addWidget(mCentralWidget, 1, 0);
+	mCentralScroller->setWidget(w);
+	w->setObjectName("DkPreferenceWidget");
 
 	connect(w, SIGNAL(infoSignal(const QString&)), this, SLOT(setInfoMessage(const QString&)));
 }
 
 void DkPreferenceTabWidget::setInfoMessage(const QString& msg) {
+
 	mInfoButton->setText(msg);
+	mInfoButton->setVisible(!msg.isEmpty());
 }
 
 QWidget* DkPreferenceTabWidget::widget() const {
-	return mCentralWidget;
+	return mCentralScroller->widget();
 }
 
 QIcon DkPreferenceTabWidget::icon() const {
@@ -231,7 +233,7 @@ QIcon DkPreferenceTabWidget::icon() const {
 }
 
 // DkGroupWidget --------------------------------------------------------------------
-DkGroupWidget::DkGroupWidget(const QString& title, QWidget* parent) : QWidget(parent) {
+DkGroupWidget::DkGroupWidget(const QString& title, QWidget* parent) : DkWidget(parent) {
 
 	setObjectName("DkGroupWidget");
 	mTitle = title;
@@ -276,7 +278,7 @@ void DkGroupWidget::paintEvent(QPaintEvent *event) {
 }
 
 // DkGeneralPreference --------------------------------------------------------------------
-DkGeneralPreference::DkGeneralPreference(QWidget* parent) : QWidget(parent) {
+DkGeneralPreference::DkGeneralPreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -289,6 +291,7 @@ void DkGeneralPreference::createLayout() {
 	QStringList themes = tm.cleanThemeNames(tm.getAvailableThemes());
 
 	QComboBox* themeBox = new QComboBox(this);
+	themeBox->setView(new QListView());
 	themeBox->setObjectName("themeBox");
 	themeBox->addItems(themes);
 	themeBox->setCurrentText(tm.cleanThemeName(tm.getCurrentThemeName()));
@@ -348,7 +351,7 @@ void DkGeneralPreference::createLayout() {
 	cbRecentFiles->setToolTip(tr("Show the History Panel on Start-Up"));
 	cbRecentFiles->setChecked(DkSettingsManager::param().app().showRecentFiles);
 
-	QCheckBox* cbLogRecentFiles = new QCheckBox(tr("Log Recent Files"), this);
+	QCheckBox* cbLogRecentFiles = new QCheckBox(tr("Remember Recent Files History"), this);
 	cbLogRecentFiles->setObjectName("logRecentFiles");
 	cbLogRecentFiles->setToolTip(tr("If checked, recent files will be saved."));
 	cbLogRecentFiles->setChecked(DkSettingsManager::param().global().logRecentFiles);
@@ -420,6 +423,7 @@ void DkGeneralPreference::createLayout() {
 
 	// language
 	QComboBox* languageCombo = new QComboBox(this);
+	languageCombo->setView(new QListView());	// fix style
 	languageCombo->setObjectName("languageCombo");
 	languageCombo->setToolTip(tr("Choose your preferred language."));
 	DkUtils::addLanguages(languageCombo, mLanguages);
@@ -612,8 +616,18 @@ void DkGeneralPreference::on_exportSettings_clicked() {
 	if (filePath.isEmpty())
 		return;
 
-	QSettings settings(filePath, QSettings::IniFormat);
-	DkSettingsManager::instance().settings().save(settings, true);
+	// try copying setting
+	// NOTE: unfortunately this won't copy ini files on unix
+	bool copied = false;
+	QFile f(DkSettingsManager::instance().param().settingsPath());
+	if (f.exists())
+		copied = f.copy(filePath);
+
+	// save settings (here we lose settings such as [CustomShortcuts])
+	if (!copied) {
+		QSettings settings(filePath, QSettings::IniFormat);
+		DkSettingsManager::instance().settings().save(settings, true);
+	}
 
 	emit infoSignal(tr("Settings exported"));
 }
@@ -642,7 +656,7 @@ void DkGeneralPreference::paintEvent(QPaintEvent *event) {
 }
 
 // DkDisplaySettings --------------------------------------------------------------------
-DkDisplayPreference::DkDisplayPreference(QWidget* parent) : QWidget(parent) {
+DkDisplayPreference::DkDisplayPreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -752,6 +766,7 @@ void DkDisplayPreference::createLayout() {
 	QLabel* fadeImageLabel = new QLabel(tr("Image Transition"), this);
 
 	QComboBox* cbTransition = new QComboBox(this);
+	cbTransition->setView(new QListView());	// fix style
 	cbTransition->setObjectName("transition");
 	cbTransition->setToolTip(tr("Choose a transition when loading a new image"));
 
@@ -794,6 +809,10 @@ void DkDisplayPreference::createLayout() {
 	displayTimeBox->setSingleStep(.2);
 	displayTimeBox->setValue(DkSettingsManager::param().slideShow().time);
 
+	QCheckBox* showPlayer = new QCheckBox(tr("Show Player"), this);
+	showPlayer->setObjectName("showPlayer");
+	showPlayer->setChecked(DkSettingsManager::param().slideShow().showPlayer);
+
 	DkGroupWidget* slideshowGroup = new DkGroupWidget(tr("Slideshow"), this);
 	slideshowGroup->addWidget(fadeImageLabel);
 	slideshowGroup->addWidget(cbTransition);
@@ -801,6 +820,7 @@ void DkDisplayPreference::createLayout() {
 	slideshowGroup->addWidget(cbAlwaysAnimate);
 	slideshowGroup->addWidget(displayTimeLabel);
 	slideshowGroup->addWidget(displayTimeBox);
+	slideshowGroup->addWidget(showPlayer);
 
 	// show crop from metadata
 	QCheckBox* showCrop = new QCheckBox(tr("Show crop rectangle"), this);
@@ -811,26 +831,13 @@ void DkDisplayPreference::createLayout() {
 	showCropGroup->addWidget(showCrop);
 
 	// left column
-	QWidget* leftWidget = new QWidget(this);
-	QVBoxLayout* leftLayout = new QVBoxLayout(leftWidget);
-	leftLayout->setAlignment(Qt::AlignTop);
-	leftLayout->addWidget(zoomGroup);
-	leftLayout->addWidget(keepZoomGroup);
-	leftLayout->addWidget(iconGroup);
-	leftLayout->addWidget(slideshowGroup);
-	leftLayout->addWidget(showCropGroup);
-
-	// right column
-	QWidget* rightWidget = new QWidget(this);
-	QVBoxLayout* rightLayout = new QVBoxLayout(rightWidget);
-	rightLayout->setAlignment(Qt::AlignTop);
-
-	QHBoxLayout* layout = new QHBoxLayout(this);
-	layout->setAlignment(Qt::AlignLeft);
-
-	layout->addWidget(leftWidget);
-	layout->addWidget(rightWidget);
-	layout->addStretch();
+	QVBoxLayout* l = new QVBoxLayout(this);
+	l->setAlignment(Qt::AlignTop);
+	l->addWidget(zoomGroup);
+	l->addWidget(keepZoomGroup);
+	l->addWidget(iconGroup);
+	l->addWidget(slideshowGroup);
+	l->addWidget(showCropGroup);
 }
 
 void DkDisplayPreference::on_interpolationBox_valueChanged(int value) const {
@@ -854,6 +861,13 @@ void DkDisplayPreference::on_displayTimeBox_valueChanged(double value) const {
 
 }
 
+void DkDisplayPreference::on_showPlayer_toggled(bool checked) const {
+
+	if (DkSettingsManager::param().slideShow().showPlayer != checked)
+		DkSettingsManager::param().slideShow().showPlayer = checked;
+
+}
+
 void DkDisplayPreference::on_iconSizeBox_valueChanged(int value) const {
 
 	if (DkSettingsManager::param().display().iconSize != value) {
@@ -948,7 +962,7 @@ void DkDisplayPreference::paintEvent(QPaintEvent *event) {
 }
 
 // DkDummySettings --------------------------------------------------------------------
-DkFilePreference::DkFilePreference(QWidget* parent) : QWidget(parent) {
+DkFilePreference::DkFilePreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -1055,28 +1069,24 @@ void DkFilePreference::createLayout() {
 	skipGroup->addWidget(skipBox);
 
 	// left column
-	QWidget* leftWidget = new QWidget(this);
-	QVBoxLayout* leftLayout = new QVBoxLayout(leftWidget);
-	leftLayout->addWidget(tempFolderGroup);
-	leftLayout->addWidget(cacheGroup);
-	leftLayout->addWidget(historyGroup);
-	leftLayout->addWidget(loadGroup);
-	leftLayout->addWidget(saveGroup);
-	leftLayout->addWidget(skipGroup);
-
-	QHBoxLayout* layout = new QHBoxLayout(this);
-	layout->setAlignment(Qt::AlignLeft);
-	layout->addWidget(leftWidget);
+	QVBoxLayout* l = new QVBoxLayout(this);
+	l->setAlignment(Qt::AlignTop);
+	l->addWidget(tempFolderGroup);
+	l->addWidget(cacheGroup);
+	l->addWidget(historyGroup);
+	l->addWidget(loadGroup);
+	l->addWidget(saveGroup);
+	l->addWidget(skipGroup);
 }
 
 void DkFilePreference::on_dirChooser_directoryChanged(const QString& dirPath) const {
 
 	bool dirExists = QDir(dirPath).exists();
-	DkSettingsManager::param().global().useTmpPath = dirExists;
 
-	if (DkSettingsManager::param().global().tmpPath != dirPath && dirExists) {
+	if (DkSettingsManager::param().global().tmpPath != dirPath && dirExists)
 		DkSettingsManager::param().global().tmpPath = dirPath;
-	}
+	else if (!dirExists)
+		DkSettingsManager::param().global().tmpPath = "";
 
 }
 
@@ -1129,7 +1139,7 @@ void DkFilePreference::paintEvent(QPaintEvent *event) {
 }
 
 // DkFileAssocationsSettings --------------------------------------------------------------------
-DkFileAssociationsPreference::DkFileAssociationsPreference(QWidget* parent) : QWidget(parent) {
+DkFileAssociationsPreference::DkFileAssociationsPreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -1162,7 +1172,6 @@ void DkFileAssociationsPreference::createLayout() {
 	filterTableView->setModel(mModel);
 	filterTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
 	filterTableView->verticalHeader()->hide();
-	//filterTableView->horizontalHeader()->hide();
 	filterTableView->setShowGrid(false);
 	filterTableView->resizeColumnsToContents();
 	filterTableView->resizeRowsToContents();
@@ -1170,6 +1179,7 @@ void DkFileAssociationsPreference::createLayout() {
 
 	// now the final widgets
 	QVBoxLayout* layout = new QVBoxLayout(this);
+	layout->setAlignment(Qt::AlignTop);
 	layout->addWidget(filterTableView);
 
 #ifdef Q_OS_WIN
@@ -1182,11 +1192,10 @@ void DkFileAssociationsPreference::createLayout() {
 
 	QWidget* bw = new QWidget(this);
 	QHBoxLayout* l = new QHBoxLayout(bw);
-
+	l->setAlignment(Qt::AlignLeft);
 	l->setContentsMargins(0, 0, 0, 0);
 	l->addWidget(openDefault);
 	l->addWidget(assocFiles);
-	l->addStretch();
 
 	layout->addWidget(bw);
 #endif
@@ -1300,7 +1309,7 @@ void DkFileAssociationsPreference::paintEvent(QPaintEvent *event) {
 }
 
 // DkAdvancedSettings --------------------------------------------------------------------
-DkAdvancedPreference::DkAdvancedPreference(QWidget* parent) : QWidget(parent) {
+DkAdvancedPreference::DkAdvancedPreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -1388,6 +1397,7 @@ void DkAdvancedPreference::createLayout() {
 	useLogGroup->addWidget(pbLog);
 
 	QVBoxLayout* layout = new QVBoxLayout(this);
+	layout->setAlignment(Qt::AlignTop);
 	layout->addWidget(loadRawGroup);
 	layout->addWidget(loadFileGroup);
 	layout->addWidget(threadsGroup);
@@ -1459,7 +1469,7 @@ void DkAdvancedPreference::paintEvent(QPaintEvent *event) {
 }
 
 // DkEditorPreference --------------------------------------------------------------------
-DkEditorPreference::DkEditorPreference(QWidget* parent) : QWidget(parent) {
+DkEditorPreference::DkEditorPreference(QWidget* parent) : DkWidget(parent) {
 
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
@@ -1496,6 +1506,9 @@ void DkEditorPreference::changeSetting(const QString& key, const QVariant& value
 
 	DefaultSettings settings;
 	DkSettingsWidget::changeSetting(settings, key, value, groups);
+
+	// update values
+	nmc::DkSettingsManager::instance().param().load();
 }
 
 void DkEditorPreference::removeSetting(const QString& key, const QStringList& groups) const {
